package sun.awt.image;

import java.awt.image.SinglePixelPackedSampleModel;
import java.awt.image.DirectColorModel;
import java.awt.image.PixelInterleavedSampleModel;
import sun.java2d.SurfaceData;
import java.awt.image.ColorModel;
import java.awt.Point;
import java.awt.image.DataBuffer;
import java.awt.image.SampleModel;
import java.awt.image.WritableRaster;

public class WritableRasterNative extends WritableRaster
{
    public static WritableRasterNative createNativeRaster(SampleModel sampleModel, DataBuffer dataBuffer) {
        return new WritableRasterNative(sampleModel, dataBuffer);
    }
    
    protected WritableRasterNative(SampleModel sampleModel, DataBuffer dataBuffer) {
        super(sampleModel, dataBuffer, new Point(0, 0));
    }
    
    public static WritableRasterNative createNativeRaster(ColorModel colorModel, SurfaceData surfaceData, int n, int h) {
        int dataType;
        Object o;
        switch (colorModel.getPixelSize()) {
            case 8:
            case 12: {
                if (colorModel.getPixelSize() == 8) {
                    dataType = 0;
                }
                else {
                    dataType = 1;
                }
                o = new PixelInterleavedSampleModel(dataType, n, h, 1, n, new int[] { 0 });
                break;
            }
            case 15:
            case 16: {
                dataType = 1;
                int[] bitMasks = new int[3];
                DirectColorModel directColorModel = (DirectColorModel)colorModel;
                bitMasks[0] = directColorModel.getRedMask();
                bitMasks[1] = directColorModel.getGreenMask();
                bitMasks[2] = directColorModel.getBlueMask();
                o = new SinglePixelPackedSampleModel(dataType, n, h, n, bitMasks);
                break;
            }
            case 24:
            case 32: {
                dataType = 3;
                int[] bitMasks2 = new int[3];
                DirectColorModel directColorModel2 = (DirectColorModel)colorModel;
                bitMasks2[0] = directColorModel2.getRedMask();
                bitMasks2[1] = directColorModel2.getGreenMask();
                bitMasks2[2] = directColorModel2.getBlueMask();
                o = new SinglePixelPackedSampleModel(dataType, n, h, n, bitMasks2);
                break;
            }
            default: {
                throw new InternalError("Unsupported depth " + colorModel.getPixelSize());
            }
        }
        return new WritableRasterNative(o, new DataBufferNative(surfaceData, dataType, n, h));
    }
}
